aeiou
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Pronounced “[ayoo](https://youtu.be/Hv6RbEOlqRo?t=24)”

## Install

We recommend you install the latest version from GitHub via

``` sh
pip install git+https://github.com/drscotthawley/aeiou.git
```

However binaries will be occasionally updated on PyPI, installed via

``` sh
pip install aeiou
```

## How to use

This is a series of utility routines developed in support of multiple
projects within [Harmonai](https://www.harmonai.org/). See individual
documentation pages for more specific instructions on how these can be
used.
